mass equivalents: # possible eventualities similar: IU: A measure of the biological activity of an ingredient. The mass equivalent of IU differs based on the ingredient. https://en.wikipedia.org/wiki/International_unit https://en.wikipedia.org/wiki/Biological_activity short list: DFE: [ Folate, Vitamin B9, Folacin ] NE: B3 -> [ Niacin ] RAE: [ Vitamin A ] AT: [ Vitamin E ] alpha-tocopherol list: [ Folate, Vitamin B9, Folacin ]: DFE, Dietary Folate Equivalent Folate: 1 μg DFE = 1 μg folates 1 μg DFE = 0.6 μg folic acid https://ods.od.nih.gov/factsheets/Folate-HealthProfessional/ DFE == dietary folate equivalents 1 mcg DFE = either ( 1 mcg food folate 0.6 mcg folic acid from fortified foods or dietary supplements consumed with foods 0.5 mcg folic acid from dietary supplements taken on an empty stomach ) Vitamin B3: Niacin: NE, Niacin Equivalent 1 mg NE = 1 mg niacinamide 1 mg NE = 1 mg inositol hexanicotinate 1 mg NE = 1 mg niacin 1 mg NE = 60 mg tryptophan Vitamin A: RAE, Retinol Activity Equivalent https://www.dietarysupplementdatabase.usda.nih.gov/Conversions.php RAE is how much retinol the body produces (on average) with each of the equivalents. Vitamin A1 == Retinol Vitamin A https://ods.od.nih.gov/factsheets/VitaminA-HealthProfessional/ 1 IU retinol = 0.3 mcg RAE 1 IU supplemental beta-carotene = 0.3 mcg RAE 1 IU dietary beta-carotene = 0.05 mcg RAE 1 IU dietary alpha-carotene or beta-cryptoxanthin = 0.025 mcg RAE 1 mcg RAE == either ( 1 mcg retinol, 2 mcg supplemental beta-carotene, 12 mcg dietary beta-carotene, or 24 mcg dietary alpha-carotene or beta-cryptoxanthin ) Vitamin D ? 1 mcg = 40 IU https://en.wikipedia.org/wiki/Vitamin_D#Dietary_intake Vitamin D1 Vitamin D2 Vitamin D3 Vitamin D2 + D3 mg alpha-tocopherol Vitamin E: 1 IU (natural) = 0.67 mg Vitamin E (as alpha-tocopherol) 1 IU (synthetic) = 0.45 mg Vitamin E (as alpha-tocopherol)